@@ -6,7 +6,7 @@ BASE_URL = "https://api2.ippanel.com/api/v1/"
 # default timeout for http client
 DEFAULT_TIMEOUT = 30
 # client version
-CLIENT_VERSION = "2.0.4"
+CLIENT_VERSION = "2.0.7"
 
 
 class Client:
@@ -45,7 +45,7 @@ class Client:
         :return: :class:`int <int>` object
         :rtype: int
         """
-        res = self.client.post("sms/send/panel/single", {
+        res = self.client.post("sms/send/webservice/single", {
             "sender": sender,
             "recipient": recipients,
             "message": message,
